"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupFormat = void 0;
const tslib_1 = require("tslib");
const enquirer_1 = require("enquirer");
const interactive_1 = require("../../../global/options/interactive");
const format_constant_1 = require("./format.constant");
const validation_1 = require("../../../core/validation");
const constants_1 = require("../constants");
function setupFormat(config) {
    var _a;
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        let format = [];
        let cfgFormat = [];
        if ((_a = config === null || config === void 0 ? void 0 : config.persist) === null || _a === void 0 ? void 0 : _a.format) {
            cfgFormat = Array.isArray(config.persist.format) ? config.persist.format : typeof config.persist.format === 'string' ? [config.persist.format] : [];
        }
        if (cfgFormat.length === 0) {
            format = constants_1.REPORT_FORMAT_VALUES;
        }
        else {
            format = cfgFormat;
        }
        if ((0, interactive_1.get)()) {
            const { f } = cfgFormat.length === 0 ? yield (0, enquirer_1.prompt)([
                {
                    type: 'multiselect',
                    name: 'f',
                    message: format_constant_1.PROMPT_PERSIST_FORMAT,
                    choices: constants_1.REPORT_FORMAT_OPTIONS,
                    initial: 0,
                    // @NOTICE typing is broken here
                    result(value) {
                        const values = value;
                        return values.map(name => { var _a; return ((_a = constants_1.REPORT_FORMAT_OPTIONS.find(i => i.name === name)) === null || _a === void 0 ? void 0 : _a.value) + ''; });
                    }
                }
            ]) : { f: cfgFormat };
            format = f;
            if ((format === null || format === void 0 ? void 0 : format.length) === 0) {
                return setupFormat(config);
            }
        }
        // Validate
        const allOf = validation_1.VALIDATORS.allOf(constants_1.REPORT_FORMAT_VALUES);
        const errors = (0, validation_1.applyValidations)(format, [
            validation_1.VALIDATORS.required,
            allOf
        ]);
        if ((0, validation_1.hasError)(errors)) {
            if (errors.required) {
                throw new Error(format_constant_1.ERROR_PERSIST_FORMAT_REQUIRED);
            }
            if (errors.allOf) {
                console.log('errors.allOf: ', errors);
                throw new Error((0, format_constant_1.ERROR_PERSIST_FORMAT_WRONG)(errors.allOf.value));
            }
        }
        return Object.assign(Object.assign({}, config), { persist: Object.assign(Object.assign({}, config === null || config === void 0 ? void 0 : config.persist), { format }) });
    });
}
exports.setupFormat = setupFormat;
//# sourceMappingURL=format.setup.js.map