"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.collectReports = void 0;
const tslib_1 = require("tslib");
const behaviors_1 = require("../../../core/processing/behaviors");
const loggin_1 = require("../../../core/loggin");
const dryRun_1 = require("../../../commands/collect/options/dryRun");
const user_flow_1 = require("../utils/user-flow");
function collectReports(cfg) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { collect, persist, assert } = cfg;
        let userFlows = [];
        // Load and run user-flows in sequential
        userFlows = (0, user_flow_1.loadFlow)(collect);
        yield (0, behaviors_1.concat)(userFlows.map(({ exports: provider, path }) => (_) => {
            provider = normalizeProviderObject(provider);
            provider = addBudgetsIfGiven(provider, assert);
            return (0, user_flow_1.collectFlow)(Object.assign(Object.assign({}, collect), { dryRun: (0, dryRun_1.get)() }), Object.assign(Object.assign({}, provider), { path }))
                .then((flow) => (0, user_flow_1.persistFlow)(flow, provider.flowOptions.name, persist))
                .then(user_flow_1.openFlowReport)
                .then(_ => cfg);
        }))(cfg);
        return Promise.resolve(cfg);
    });
}
exports.collectReports = collectReports;
function normalizeProviderObject(provider) {
    var _a, _b;
    provider = provider || {};
    if (((_a = provider.flowOptions) === null || _a === void 0 ? void 0 : _a.config) === undefined) {
        provider.flowOptions.config = {};
        if (((_b = provider.flowOptions.config) === null || _b === void 0 ? void 0 : _b.settings) === undefined) {
            // @ts-ignore
            provider.flowOptions.config.settings = {};
        }
    }
    return provider;
}
function addBudgetsIfGiven(provider, assertOptions = {}) {
    const { budgetPath, budgets } = assertOptions;
    if (budgetPath) {
        (0, loggin_1.logVerbose)(`CLI options --budgetPath or .user-flowrc.json configuration ${budgetPath} is used instead of a potential configuration in the user flow`);
        // @ts-ignore
        provider.flowOptions.config.settings.budgets = budgetPath;
    }
    else if (budgets) {
        (0, loggin_1.logVerbose)('.user-flowrc.json configuration is used instead of a potential configuration in the user flow');
        // @ts-ignore
        provider.flowOptions.config.settings.budgets = budgets;
    }
    return provider;
}
//# sourceMappingURL=collect-reports.js.map