"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getInitCommandOptionsFromArgv = exports.addUserFlow = exports.getExamplePathDest = exports.getExamplePathSrc = void 0;
const path_1 = require("path");
const file_1 = require("../../core/file");
const loggin_1 = require("../../core/loggin");
const FlowExampleMap = {
    'basic-navigation': 'order-coffee.uf.ts'
};
function getExamplePathSrc(flowExample, folder) {
    const fileName = FlowExampleMap[flowExample];
    return (0, path_1.join)(__dirname, 'static', fileName);
}
exports.getExamplePathSrc = getExamplePathSrc;
function getExamplePathDest(flowExample, folder) {
    const fileName = FlowExampleMap[flowExample];
    return (0, path_1.join)(folder, fileName);
}
exports.getExamplePathDest = getExamplePathDest;
function addUserFlow(flowExample, folder) {
    if (!Object.keys(FlowExampleMap).includes(flowExample)) {
    }
    const fileName = FlowExampleMap[flowExample];
    const exampleSourceLocation = (0, path_1.join)(__dirname, 'static', fileName);
    const exampleDestination = (0, path_1.join)(folder, fileName);
    if ((0, file_1.readFile)(exampleDestination) !== '') {
        throw new Error(`No flow example given for name ${flowExample}.`);
    }
    const fileContent = (0, file_1.readFile)(exampleSourceLocation, { fail: true }).toString();
    (0, file_1.writeFile)(exampleDestination, fileContent);
    (0, loggin_1.log)(`setup user-flow for basic navigation in ${folder} successfully`);
}
exports.addUserFlow = addUserFlow;
function getInitCommandOptionsFromArgv(argv) {
    const { url, ufPath, serveCommand, awaitServeStdout, outPath, format, budgetPath, budgets } = argv;
    let collect = {};
    url && (collect.url = url);
    ufPath && (collect.ufPath = ufPath);
    // optional
    serveCommand && (collect.serveCommand = serveCommand);
    awaitServeStdout && (collect.awaitServeStdout = awaitServeStdout);
    let persist = {};
    outPath && (persist.outPath = outPath);
    format && (persist.format = format);
    let assert = {};
    budgetPath && (assert.budgetPath = budgetPath);
    budgets && (assert.budgets = budgets);
    return { collect, persist, assert };
}
exports.getInitCommandOptionsFromArgv = getInitCommandOptionsFromArgv;
//# sourceMappingURL=utils.js.map